
## imgcat: A simple tool to show image in terminal


<p align="center">
    <a href="https://github.com/Snape-max/imgcat" target="_blank" style="margin-right: 20px; font-style: normal; text-decoration: none;">
        <img src="https://img.shields.io/github/stars/Snape-max/imgcat" alt="Github Stars" />
    </a>
    <a href="https://github.com/Snape-max/imgcat" target="_blank" style="margin-right: 20px; font-style: normal; text-decoration: none;">
        <img src="https://img.shields.io/github/forks/Snape-max/imgcat" alt="Github Forks" />
    </a>
    <a href="https://github.com/Snape-max/imgcat" target="_blank" style="margin-right: 20px; font-style: normal; text-decoration: none;">
        <img src="https://img.shields.io/github/languages/code-size/Snape-max/imgcat" alt="Code-size" />
    </a>
    <a href="https://github.com/Snape-max/imgcat">
        <img src="https://img.shields.io/github/v/release/Snape-max/imgcat"
            alt="Latest Release">
    </a>
</p>

## Installation

```bash
git clone https://github.com/Snape-max/imagecat.git
cd imagecat
python install .
```

or

```bash
pip install git+https://github.com/Snape-max/imgcat.git
```


## Requirements

- Python 3.6+
- Pillow for image reading


## Usage

```bash
imgcat <image_path>
```

## Display

<img src="./asset/screenshot.png" width="800">
